@@ -442,7 +442,7 @@ ssize_t iio_device_get_sample_size_mask(const struct iio_device *dev,
 		const uint32_t *mask, size_t words)
 {
 	ssize_t size = 0;
-	unsigned int i;
+	unsigned int i, largest = 1;
 	const struct iio_channel *prev = NULL;
 
 	if (words != (dev->nb_channels + 31) / 32)
@@ -463,6 +463,9 @@ ssize_t iio_device_get_sample_size_mask(const struct iio_device *dev,
 			continue;
 		}
 
+		if (length > largest)
+			largest = length;
+
 		if (size % length)
 			size += 2 * length - (size % length);
 		else
@@ -470,6 +473,10 @@ ssize_t iio_device_get_sample_size_mask(const struct iio_device *dev,
 
 		prev = chn;
 	}
+
+	if (size % largest)
+		size += largest - (size % largest);
+
 	return size;
 }
 
