@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: LGPL-2.1-or-later
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * iio_info - Part of Industrial I/O (IIO) utilities
  *
@@ -53,20 +53,13 @@ int main(int argc, char **argv)
 	int c;
 	unsigned int i, major, minor;
 	char git_tag[8];
-	int ret;
 	struct option *opts;
+	int ret = EXIT_FAILURE;
 
 	argw = dup_argv(MY_NAME, argc, argv);
 
-	iio_library_get_version(&major, &minor, git_tag);
-	printf("Library version: %u.%u (git tag: %s)\n", major, minor, git_tag);
-
-	printf("Compiled with backends:");
-	for (i = 0; i < iio_get_backends_count(); i++)
-		printf(" %s", iio_get_backend(i));
-	printf("\n");
-
-	ctx = handle_common_opts(MY_NAME, argc, argw, MY_OPTS, options, options_descriptions);
+	ctx = handle_common_opts(MY_NAME, argc, argw, MY_OPTS,
+				 options, options_descriptions, &ret);
 	opts = add_common_options(options);
 	if (!opts) {
 		fprintf(stderr, "Failed to add common options\n");
@@ -77,6 +70,7 @@ int main(int argc, char **argv)
 		switch (c) {
 			/* All these are handled in the common */
 		case 'h':
+		case 'V':
 		case 'n':
 		case 'x':
 		case 'u':
@@ -89,8 +83,8 @@ int main(int argc, char **argv)
 				optind++;
 			break;
 		case 's':
-			autodetect_context(false, MY_NAME, NULL);
-			return EXIT_SUCCESS;
+			autodetect_context(false, MY_NAME, NULL, &ret);
+			return ret;
 		case '?':
 			printf("Unknown argument '%c'\n", c);
 			return EXIT_FAILURE;
@@ -105,8 +99,9 @@ int main(int argc, char **argv)
 	}
 
 	if (!ctx)
-		return EXIT_FAILURE;
+		return ret;
 
+	version(MY_NAME);
 	printf("IIO context created with %s backend.\n",
 			iio_context_get_name(ctx));
 
